/*******************************************************************************
* File Name: UAR.h
* Version 2.50
*
* Description:
*  Contains the function prototypes and constants available to the UART
*  user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_UART_UAR_H)
#define CY_UART_UAR_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"


/***************************************
* Conditional Compilation Parameters
***************************************/

#define UAR_RX_ENABLED                     (0u)
#define UAR_TX_ENABLED                     (1u)
#define UAR_HD_ENABLED                     (0u)
#define UAR_RX_INTERRUPT_ENABLED           (0u)
#define UAR_TX_INTERRUPT_ENABLED           (0u)
#define UAR_INTERNAL_CLOCK_USED            (1u)
#define UAR_RXHW_ADDRESS_ENABLED           (0u)
#define UAR_OVER_SAMPLE_COUNT              (8u)
#define UAR_PARITY_TYPE                    (0u)
#define UAR_PARITY_TYPE_SW                 (0u)
#define UAR_BREAK_DETECT                   (0u)
#define UAR_BREAK_BITS_TX                  (13u)
#define UAR_BREAK_BITS_RX                  (13u)
#define UAR_TXCLKGEN_DP                    (1u)
#define UAR_USE23POLLING                   (1u)
#define UAR_FLOW_CONTROL                   (0u)
#define UAR_CLK_FREQ                       (0u)
#define UAR_TX_BUFFER_SIZE                 (4u)
#define UAR_RX_BUFFER_SIZE                 (4u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component UART_v2_50 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */

#if defined(UAR_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG)
    #define UAR_CONTROL_REG_REMOVED            (0u)
#else
    #define UAR_CONTROL_REG_REMOVED            (1u)
#endif /* End UAR_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */


/***************************************
*      Data Structure Definition
***************************************/

/* Sleep Mode API Support */
typedef struct UAR_backupStruct_
{
    uint8 enableState;

    #if(UAR_CONTROL_REG_REMOVED == 0u)
        uint8 cr;
    #endif /* End UAR_CONTROL_REG_REMOVED */

} UAR_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void UAR_Start(void) ;
void UAR_Stop(void) ;
uint8 UAR_ReadControlRegister(void) ;
void UAR_WriteControlRegister(uint8 control) ;

void UAR_Init(void) ;
void UAR_Enable(void) ;
void UAR_SaveConfig(void) ;
void UAR_RestoreConfig(void) ;
void UAR_Sleep(void) ;
void UAR_Wakeup(void) ;

/* Only if RX is enabled */
#if( (UAR_RX_ENABLED) || (UAR_HD_ENABLED) )

    #if (UAR_RX_INTERRUPT_ENABLED)
        #define UAR_EnableRxInt()  CyIntEnable (UAR_RX_VECT_NUM)
        #define UAR_DisableRxInt() CyIntDisable(UAR_RX_VECT_NUM)
        CY_ISR_PROTO(UAR_RXISR);
    #endif /* UAR_RX_INTERRUPT_ENABLED */

    void UAR_SetRxAddressMode(uint8 addressMode)
                                                           ;
    void UAR_SetRxAddress1(uint8 address) ;
    void UAR_SetRxAddress2(uint8 address) ;

    void  UAR_SetRxInterruptMode(uint8 intSrc) ;
    uint8 UAR_ReadRxData(void) ;
    uint8 UAR_ReadRxStatus(void) ;
    uint8 UAR_GetChar(void) ;
    uint16 UAR_GetByte(void) ;
    uint8 UAR_GetRxBufferSize(void)
                                                            ;
    void UAR_ClearRxBuffer(void) ;

    /* Obsolete functions, defines for backward compatible */
    #define UAR_GetRxInterruptSource   UAR_ReadRxStatus

#endif /* End (UAR_RX_ENABLED) || (UAR_HD_ENABLED) */

/* Only if TX is enabled */
#if(UAR_TX_ENABLED || UAR_HD_ENABLED)

    #if(UAR_TX_INTERRUPT_ENABLED)
        #define UAR_EnableTxInt()  CyIntEnable (UAR_TX_VECT_NUM)
        #define UAR_DisableTxInt() CyIntDisable(UAR_TX_VECT_NUM)
        #define UAR_SetPendingTxInt() CyIntSetPending(UAR_TX_VECT_NUM)
        #define UAR_ClearPendingTxInt() CyIntClearPending(UAR_TX_VECT_NUM)
        CY_ISR_PROTO(UAR_TXISR);
    #endif /* UAR_TX_INTERRUPT_ENABLED */

    void UAR_SetTxInterruptMode(uint8 intSrc) ;
    void UAR_WriteTxData(uint8 txDataByte) ;
    uint8 UAR_ReadTxStatus(void) ;
    void UAR_PutChar(uint8 txDataByte) ;
    void UAR_PutString(const char8 string[]) ;
    void UAR_PutArray(const uint8 string[], uint8 byteCount)
                                                            ;
    void UAR_PutCRLF(uint8 txDataByte) ;
    void UAR_ClearTxBuffer(void) ;
    void UAR_SetTxAddressMode(uint8 addressMode) ;
    void UAR_SendBreak(uint8 retMode) ;
    uint8 UAR_GetTxBufferSize(void)
                                                            ;
    /* Obsolete functions, defines for backward compatible */
    #define UAR_PutStringConst         UAR_PutString
    #define UAR_PutArrayConst          UAR_PutArray
    #define UAR_GetTxInterruptSource   UAR_ReadTxStatus

#endif /* End UAR_TX_ENABLED || UAR_HD_ENABLED */

#if(UAR_HD_ENABLED)
    void UAR_LoadRxConfig(void) ;
    void UAR_LoadTxConfig(void) ;
#endif /* End UAR_HD_ENABLED */


/* Communication bootloader APIs */
#if defined(CYDEV_BOOTLOADER_IO_COMP) && ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_UAR) || \
                                          (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))
    /* Physical layer functions */
    void    UAR_CyBtldrCommStart(void) CYSMALL ;
    void    UAR_CyBtldrCommStop(void) CYSMALL ;
    void    UAR_CyBtldrCommReset(void) CYSMALL ;
    cystatus UAR_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;
    cystatus UAR_CyBtldrCommRead(uint8 pData[], uint16 size, uint16 * count, uint8 timeOut) CYSMALL
             ;

    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_UAR)
        #define CyBtldrCommStart    UAR_CyBtldrCommStart
        #define CyBtldrCommStop     UAR_CyBtldrCommStop
        #define CyBtldrCommReset    UAR_CyBtldrCommReset
        #define CyBtldrCommWrite    UAR_CyBtldrCommWrite
        #define CyBtldrCommRead     UAR_CyBtldrCommRead
    #endif  /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_UAR) */

    /* Byte to Byte time out for detecting end of block data from host */
    #define UAR_BYTE2BYTE_TIME_OUT (25u)
    #define UAR_PACKET_EOP         (0x17u) /* End of packet defined by bootloader */
    #define UAR_WAIT_EOP_DELAY     (5u)    /* Additional 5ms to wait for End of packet */
    #define UAR_BL_CHK_DELAY_MS    (1u)    /* Time Out quantity equal 1mS */

#endif /* CYDEV_BOOTLOADER_IO_COMP */


/***************************************
*          API Constants
***************************************/
/* Parameters for SetTxAddressMode API*/
#define UAR_SET_SPACE      (0x00u)
#define UAR_SET_MARK       (0x01u)

/* Status Register definitions */
#if( (UAR_TX_ENABLED) || (UAR_HD_ENABLED) )
    #if(UAR_TX_INTERRUPT_ENABLED)
        #define UAR_TX_VECT_NUM            (uint8)UAR_TXInternalInterrupt__INTC_NUMBER
        #define UAR_TX_PRIOR_NUM           (uint8)UAR_TXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* UAR_TX_INTERRUPT_ENABLED */

    #define UAR_TX_STS_COMPLETE_SHIFT          (0x00u)
    #define UAR_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
    #define UAR_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #if(UAR_TX_ENABLED)
        #define UAR_TX_STS_FIFO_FULL_SHIFT     (0x02u)
    #else /* (UAR_HD_ENABLED) */
        #define UAR_TX_STS_FIFO_FULL_SHIFT     (0x05u)  /* Needs MD=0 */
    #endif /* (UAR_TX_ENABLED) */

    #define UAR_TX_STS_COMPLETE            (uint8)(0x01u << UAR_TX_STS_COMPLETE_SHIFT)
    #define UAR_TX_STS_FIFO_EMPTY          (uint8)(0x01u << UAR_TX_STS_FIFO_EMPTY_SHIFT)
    #define UAR_TX_STS_FIFO_FULL           (uint8)(0x01u << UAR_TX_STS_FIFO_FULL_SHIFT)
    #define UAR_TX_STS_FIFO_NOT_FULL       (uint8)(0x01u << UAR_TX_STS_FIFO_NOT_FULL_SHIFT)
#endif /* End (UAR_TX_ENABLED) || (UAR_HD_ENABLED)*/

#if( (UAR_RX_ENABLED) || (UAR_HD_ENABLED) )
    #if(UAR_RX_INTERRUPT_ENABLED)
        #define UAR_RX_VECT_NUM            (uint8)UAR_RXInternalInterrupt__INTC_NUMBER
        #define UAR_RX_PRIOR_NUM           (uint8)UAR_RXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* UAR_RX_INTERRUPT_ENABLED */
    #define UAR_RX_STS_MRKSPC_SHIFT            (0x00u)
    #define UAR_RX_STS_BREAK_SHIFT             (0x01u)
    #define UAR_RX_STS_PAR_ERROR_SHIFT         (0x02u)
    #define UAR_RX_STS_STOP_ERROR_SHIFT        (0x03u)
    #define UAR_RX_STS_OVERRUN_SHIFT           (0x04u)
    #define UAR_RX_STS_FIFO_NOTEMPTY_SHIFT     (0x05u)
    #define UAR_RX_STS_ADDR_MATCH_SHIFT        (0x06u)
    #define UAR_RX_STS_SOFT_BUFF_OVER_SHIFT    (0x07u)

    #define UAR_RX_STS_MRKSPC           (uint8)(0x01u << UAR_RX_STS_MRKSPC_SHIFT)
    #define UAR_RX_STS_BREAK            (uint8)(0x01u << UAR_RX_STS_BREAK_SHIFT)
    #define UAR_RX_STS_PAR_ERROR        (uint8)(0x01u << UAR_RX_STS_PAR_ERROR_SHIFT)
    #define UAR_RX_STS_STOP_ERROR       (uint8)(0x01u << UAR_RX_STS_STOP_ERROR_SHIFT)
    #define UAR_RX_STS_OVERRUN          (uint8)(0x01u << UAR_RX_STS_OVERRUN_SHIFT)
    #define UAR_RX_STS_FIFO_NOTEMPTY    (uint8)(0x01u << UAR_RX_STS_FIFO_NOTEMPTY_SHIFT)
    #define UAR_RX_STS_ADDR_MATCH       (uint8)(0x01u << UAR_RX_STS_ADDR_MATCH_SHIFT)
    #define UAR_RX_STS_SOFT_BUFF_OVER   (uint8)(0x01u << UAR_RX_STS_SOFT_BUFF_OVER_SHIFT)
    #define UAR_RX_HW_MASK                     (0x7Fu)
#endif /* End (UAR_RX_ENABLED) || (UAR_HD_ENABLED) */

/* Control Register definitions */
#define UAR_CTRL_HD_SEND_SHIFT                 (0x00u) /* 1 enable TX part in Half Duplex mode */
#define UAR_CTRL_HD_SEND_BREAK_SHIFT           (0x01u) /* 1 send BREAK signal in Half Duplez mode */
#define UAR_CTRL_MARK_SHIFT                    (0x02u) /* 1 sets mark, 0 sets space */
#define UAR_CTRL_PARITY_TYPE0_SHIFT            (0x03u) /* Defines the type of parity implemented */
#define UAR_CTRL_PARITY_TYPE1_SHIFT            (0x04u) /* Defines the type of parity implemented */
#define UAR_CTRL_RXADDR_MODE0_SHIFT            (0x05u)
#define UAR_CTRL_RXADDR_MODE1_SHIFT            (0x06u)
#define UAR_CTRL_RXADDR_MODE2_SHIFT            (0x07u)

#define UAR_CTRL_HD_SEND               (uint8)(0x01u << UAR_CTRL_HD_SEND_SHIFT)
#define UAR_CTRL_HD_SEND_BREAK         (uint8)(0x01u << UAR_CTRL_HD_SEND_BREAK_SHIFT)
#define UAR_CTRL_MARK                  (uint8)(0x01u << UAR_CTRL_MARK_SHIFT)
#define UAR_CTRL_PARITY_TYPE_MASK      (uint8)(0x03u << UAR_CTRL_PARITY_TYPE0_SHIFT)
#define UAR_CTRL_RXADDR_MODE_MASK      (uint8)(0x07u << UAR_CTRL_RXADDR_MODE0_SHIFT)

/* StatusI Register Interrupt Enable Control Bits. As defined by the Register map for the AUX Control Register */
#define UAR_INT_ENABLE                         (0x10u)

/* Bit Counter (7-bit) Control Register Bit Definitions. As defined by the Register map for the AUX Control Register */
#define UAR_CNTR_ENABLE                        (0x20u)

/*   Constants for SendBreak() "retMode" parameter  */
#define UAR_SEND_BREAK                         (0x00u)
#define UAR_WAIT_FOR_COMPLETE_REINIT           (0x01u)
#define UAR_REINIT                             (0x02u)
#define UAR_SEND_WAIT_REINIT                   (0x03u)

#define UAR_OVER_SAMPLE_8                      (8u)
#define UAR_OVER_SAMPLE_16                     (16u)

#define UAR_BIT_CENTER                         (UAR_OVER_SAMPLE_COUNT - 2u)

#define UAR_FIFO_LENGTH                        (4u)
#define UAR_NUMBER_OF_START_BIT                (1u)
#define UAR_MAX_BYTE_VALUE                     (0xFFu)

/* 8X always for count7 implementation */
#define UAR_TXBITCTR_BREAKBITS8X   ((UAR_BREAK_BITS_TX * UAR_OVER_SAMPLE_8) - 1u)
/* 8X or 16X for DP implementation */
#define UAR_TXBITCTR_BREAKBITS ((UAR_BREAK_BITS_TX * UAR_OVER_SAMPLE_COUNT) - 1u)

#define UAR_HALF_BIT_COUNT   \
                            (((UAR_OVER_SAMPLE_COUNT / 2u) + (UAR_USE23POLLING * 1u)) - 2u)
#if (UAR_OVER_SAMPLE_COUNT == UAR_OVER_SAMPLE_8)
    #define UAR_HD_TXBITCTR_INIT   (((UAR_BREAK_BITS_TX + \
                            UAR_NUMBER_OF_START_BIT) * UAR_OVER_SAMPLE_COUNT) - 1u)

    /* This parameter is increased on the 2 in 2 out of 3 mode to sample voting in the middle */
    #define UAR_RXBITCTR_INIT  ((((UAR_BREAK_BITS_RX + UAR_NUMBER_OF_START_BIT) \
                            * UAR_OVER_SAMPLE_COUNT) + UAR_HALF_BIT_COUNT) - 1u)

#else /* UAR_OVER_SAMPLE_COUNT == UAR_OVER_SAMPLE_16 */
    #define UAR_HD_TXBITCTR_INIT   ((8u * UAR_OVER_SAMPLE_COUNT) - 1u)
    /* 7bit counter need one more bit for OverSampleCount = 16 */
    #define UAR_RXBITCTR_INIT      (((7u * UAR_OVER_SAMPLE_COUNT) - 1u) + \
                                                      UAR_HALF_BIT_COUNT)
#endif /* End UAR_OVER_SAMPLE_COUNT */

#define UAR_HD_RXBITCTR_INIT                   UAR_RXBITCTR_INIT


/***************************************
* Global variables external identifier
***************************************/

extern uint8 UAR_initVar;
#if (UAR_TX_INTERRUPT_ENABLED && UAR_TX_ENABLED)
    extern volatile uint8 UAR_txBuffer[UAR_TX_BUFFER_SIZE];
    extern volatile uint8 UAR_txBufferRead;
    extern uint8 UAR_txBufferWrite;
#endif /* (UAR_TX_INTERRUPT_ENABLED && UAR_TX_ENABLED) */
#if (UAR_RX_INTERRUPT_ENABLED && (UAR_RX_ENABLED || UAR_HD_ENABLED))
    extern uint8 UAR_errorStatus;
    extern volatile uint8 UAR_rxBuffer[UAR_RX_BUFFER_SIZE];
    extern volatile uint8 UAR_rxBufferRead;
    extern volatile uint8 UAR_rxBufferWrite;
    extern volatile uint8 UAR_rxBufferLoopDetect;
    extern volatile uint8 UAR_rxBufferOverflow;
    #if (UAR_RXHW_ADDRESS_ENABLED)
        extern volatile uint8 UAR_rxAddressMode;
        extern volatile uint8 UAR_rxAddressDetected;
    #endif /* (UAR_RXHW_ADDRESS_ENABLED) */
#endif /* (UAR_RX_INTERRUPT_ENABLED && (UAR_RX_ENABLED || UAR_HD_ENABLED)) */


/***************************************
* Enumerated Types and Parameters
***************************************/

#define UAR__B_UART__AM_SW_BYTE_BYTE 1
#define UAR__B_UART__AM_SW_DETECT_TO_BUFFER 2
#define UAR__B_UART__AM_HW_BYTE_BY_BYTE 3
#define UAR__B_UART__AM_HW_DETECT_TO_BUFFER 4
#define UAR__B_UART__AM_NONE 0

#define UAR__B_UART__NONE_REVB 0
#define UAR__B_UART__EVEN_REVB 1
#define UAR__B_UART__ODD_REVB 2
#define UAR__B_UART__MARK_SPACE_REVB 3



/***************************************
*    Initial Parameter Constants
***************************************/

/* UART shifts max 8 bits, Mark/Space functionality working if 9 selected */
#define UAR_NUMBER_OF_DATA_BITS    ((8u > 8u) ? 8u : 8u)
#define UAR_NUMBER_OF_STOP_BITS    (1u)

#if (UAR_RXHW_ADDRESS_ENABLED)
    #define UAR_RX_ADDRESS_MODE    (0u)
    #define UAR_RX_HW_ADDRESS1     (0u)
    #define UAR_RX_HW_ADDRESS2     (0u)
#endif /* (UAR_RXHW_ADDRESS_ENABLED) */

#define UAR_INIT_RX_INTERRUPTS_MASK \
                                  (uint8)((0 << UAR_RX_STS_FIFO_NOTEMPTY_SHIFT) \
                                        | (0 << UAR_RX_STS_MRKSPC_SHIFT) \
                                        | (0 << UAR_RX_STS_ADDR_MATCH_SHIFT) \
                                        | (0 << UAR_RX_STS_PAR_ERROR_SHIFT) \
                                        | (0 << UAR_RX_STS_STOP_ERROR_SHIFT) \
                                        | (0 << UAR_RX_STS_BREAK_SHIFT) \
                                        | (0 << UAR_RX_STS_OVERRUN_SHIFT))

#define UAR_INIT_TX_INTERRUPTS_MASK \
                                  (uint8)((0 << UAR_TX_STS_COMPLETE_SHIFT) \
                                        | (0 << UAR_TX_STS_FIFO_EMPTY_SHIFT) \
                                        | (0 << UAR_TX_STS_FIFO_FULL_SHIFT) \
                                        | (0 << UAR_TX_STS_FIFO_NOT_FULL_SHIFT))


/***************************************
*              Registers
***************************************/

#ifdef UAR_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define UAR_CONTROL_REG \
                            (* (reg8 *) UAR_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
    #define UAR_CONTROL_PTR \
                            (  (reg8 *) UAR_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG )
#endif /* End UAR_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(UAR_TX_ENABLED)
    #define UAR_TXDATA_REG          (* (reg8 *) UAR_BUART_sTX_TxShifter_u0__F0_REG)
    #define UAR_TXDATA_PTR          (  (reg8 *) UAR_BUART_sTX_TxShifter_u0__F0_REG)
    #define UAR_TXDATA_AUX_CTL_REG  (* (reg8 *) UAR_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define UAR_TXDATA_AUX_CTL_PTR  (  (reg8 *) UAR_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define UAR_TXSTATUS_REG        (* (reg8 *) UAR_BUART_sTX_TxSts__STATUS_REG)
    #define UAR_TXSTATUS_PTR        (  (reg8 *) UAR_BUART_sTX_TxSts__STATUS_REG)
    #define UAR_TXSTATUS_MASK_REG   (* (reg8 *) UAR_BUART_sTX_TxSts__MASK_REG)
    #define UAR_TXSTATUS_MASK_PTR   (  (reg8 *) UAR_BUART_sTX_TxSts__MASK_REG)
    #define UAR_TXSTATUS_ACTL_REG   (* (reg8 *) UAR_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)
    #define UAR_TXSTATUS_ACTL_PTR   (  (reg8 *) UAR_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)

    /* DP clock */
    #if(UAR_TXCLKGEN_DP)
        #define UAR_TXBITCLKGEN_CTR_REG        \
                                        (* (reg8 *) UAR_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define UAR_TXBITCLKGEN_CTR_PTR        \
                                        (  (reg8 *) UAR_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define UAR_TXBITCLKTX_COMPLETE_REG    \
                                        (* (reg8 *) UAR_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
        #define UAR_TXBITCLKTX_COMPLETE_PTR    \
                                        (  (reg8 *) UAR_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
    #else     /* Count7 clock*/
        #define UAR_TXBITCTR_PERIOD_REG    \
                                        (* (reg8 *) UAR_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define UAR_TXBITCTR_PERIOD_PTR    \
                                        (  (reg8 *) UAR_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define UAR_TXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) UAR_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define UAR_TXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) UAR_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define UAR_TXBITCTR_COUNTER_REG   \
                                        (* (reg8 *) UAR_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
        #define UAR_TXBITCTR_COUNTER_PTR   \
                                        (  (reg8 *) UAR_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
    #endif /* UAR_TXCLKGEN_DP */

#endif /* End UAR_TX_ENABLED */

#if(UAR_HD_ENABLED)

    #define UAR_TXDATA_REG             (* (reg8 *) UAR_BUART_sRX_RxShifter_u0__F1_REG )
    #define UAR_TXDATA_PTR             (  (reg8 *) UAR_BUART_sRX_RxShifter_u0__F1_REG )
    #define UAR_TXDATA_AUX_CTL_REG     (* (reg8 *) UAR_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)
    #define UAR_TXDATA_AUX_CTL_PTR     (  (reg8 *) UAR_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define UAR_TXSTATUS_REG           (* (reg8 *) UAR_BUART_sRX_RxSts__STATUS_REG )
    #define UAR_TXSTATUS_PTR           (  (reg8 *) UAR_BUART_sRX_RxSts__STATUS_REG )
    #define UAR_TXSTATUS_MASK_REG      (* (reg8 *) UAR_BUART_sRX_RxSts__MASK_REG )
    #define UAR_TXSTATUS_MASK_PTR      (  (reg8 *) UAR_BUART_sRX_RxSts__MASK_REG )
    #define UAR_TXSTATUS_ACTL_REG      (* (reg8 *) UAR_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define UAR_TXSTATUS_ACTL_PTR      (  (reg8 *) UAR_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End UAR_HD_ENABLED */

#if( (UAR_RX_ENABLED) || (UAR_HD_ENABLED) )
    #define UAR_RXDATA_REG             (* (reg8 *) UAR_BUART_sRX_RxShifter_u0__F0_REG )
    #define UAR_RXDATA_PTR             (  (reg8 *) UAR_BUART_sRX_RxShifter_u0__F0_REG )
    #define UAR_RXADDRESS1_REG         (* (reg8 *) UAR_BUART_sRX_RxShifter_u0__D0_REG )
    #define UAR_RXADDRESS1_PTR         (  (reg8 *) UAR_BUART_sRX_RxShifter_u0__D0_REG )
    #define UAR_RXADDRESS2_REG         (* (reg8 *) UAR_BUART_sRX_RxShifter_u0__D1_REG )
    #define UAR_RXADDRESS2_PTR         (  (reg8 *) UAR_BUART_sRX_RxShifter_u0__D1_REG )
    #define UAR_RXDATA_AUX_CTL_REG     (* (reg8 *) UAR_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define UAR_RXBITCTR_PERIOD_REG    (* (reg8 *) UAR_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define UAR_RXBITCTR_PERIOD_PTR    (  (reg8 *) UAR_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define UAR_RXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) UAR_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define UAR_RXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) UAR_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define UAR_RXBITCTR_COUNTER_REG   (* (reg8 *) UAR_BUART_sRX_RxBitCounter__COUNT_REG )
    #define UAR_RXBITCTR_COUNTER_PTR   (  (reg8 *) UAR_BUART_sRX_RxBitCounter__COUNT_REG )

    #define UAR_RXSTATUS_REG           (* (reg8 *) UAR_BUART_sRX_RxSts__STATUS_REG )
    #define UAR_RXSTATUS_PTR           (  (reg8 *) UAR_BUART_sRX_RxSts__STATUS_REG )
    #define UAR_RXSTATUS_MASK_REG      (* (reg8 *) UAR_BUART_sRX_RxSts__MASK_REG )
    #define UAR_RXSTATUS_MASK_PTR      (  (reg8 *) UAR_BUART_sRX_RxSts__MASK_REG )
    #define UAR_RXSTATUS_ACTL_REG      (* (reg8 *) UAR_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define UAR_RXSTATUS_ACTL_PTR      (  (reg8 *) UAR_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End  (UAR_RX_ENABLED) || (UAR_HD_ENABLED) */

#if(UAR_INTERNAL_CLOCK_USED)
    /* Register to enable or disable the digital clocks */
    #define UAR_INTCLOCK_CLKEN_REG     (* (reg8 *) UAR_IntClock__PM_ACT_CFG)
    #define UAR_INTCLOCK_CLKEN_PTR     (  (reg8 *) UAR_IntClock__PM_ACT_CFG)

    /* Clock mask for this clock. */
    #define UAR_INTCLOCK_CLKEN_MASK    UAR_IntClock__PM_ACT_MSK
#endif /* End UAR_INTERNAL_CLOCK_USED */


/***************************************
*       Register Constants
***************************************/

#if(UAR_TX_ENABLED)
    #define UAR_TX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End UAR_TX_ENABLED */

#if(UAR_HD_ENABLED)
    #define UAR_TX_FIFO_CLR            (0x02u) /* FIFO1 CLR */
#endif /* End UAR_HD_ENABLED */

#if( (UAR_RX_ENABLED) || (UAR_HD_ENABLED) )
    #define UAR_RX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End  (UAR_RX_ENABLED) || (UAR_HD_ENABLED) */


/***************************************
* The following code is DEPRECATED and
* should not be used in new projects.
***************************************/

/* UART v2_40 obsolete definitions */
#define UAR_WAIT_1_MS      UAR_BL_CHK_DELAY_MS   

#define UAR_TXBUFFERSIZE   UAR_TX_BUFFER_SIZE
#define UAR_RXBUFFERSIZE   UAR_RX_BUFFER_SIZE

#if (UAR_RXHW_ADDRESS_ENABLED)
    #define UAR_RXADDRESSMODE  UAR_RX_ADDRESS_MODE
    #define UAR_RXHWADDRESS1   UAR_RX_HW_ADDRESS1
    #define UAR_RXHWADDRESS2   UAR_RX_HW_ADDRESS2
    /* Backward compatible define */
    #define UAR_RXAddressMode  UAR_RXADDRESSMODE
#endif /* (UAR_RXHW_ADDRESS_ENABLED) */

/* UART v2_30 obsolete definitions */
#define UAR_initvar                    UAR_initVar

#define UAR_RX_Enabled                 UAR_RX_ENABLED
#define UAR_TX_Enabled                 UAR_TX_ENABLED
#define UAR_HD_Enabled                 UAR_HD_ENABLED
#define UAR_RX_IntInterruptEnabled     UAR_RX_INTERRUPT_ENABLED
#define UAR_TX_IntInterruptEnabled     UAR_TX_INTERRUPT_ENABLED
#define UAR_InternalClockUsed          UAR_INTERNAL_CLOCK_USED
#define UAR_RXHW_Address_Enabled       UAR_RXHW_ADDRESS_ENABLED
#define UAR_OverSampleCount            UAR_OVER_SAMPLE_COUNT
#define UAR_ParityType                 UAR_PARITY_TYPE

#if( UAR_TX_ENABLED && (UAR_TXBUFFERSIZE > UAR_FIFO_LENGTH))
    #define UAR_TXBUFFER               UAR_txBuffer
    #define UAR_TXBUFFERREAD           UAR_txBufferRead
    #define UAR_TXBUFFERWRITE          UAR_txBufferWrite
#endif /* End UAR_TX_ENABLED */
#if( ( UAR_RX_ENABLED || UAR_HD_ENABLED ) && \
     (UAR_RXBUFFERSIZE > UAR_FIFO_LENGTH) )
    #define UAR_RXBUFFER               UAR_rxBuffer
    #define UAR_RXBUFFERREAD           UAR_rxBufferRead
    #define UAR_RXBUFFERWRITE          UAR_rxBufferWrite
    #define UAR_RXBUFFERLOOPDETECT     UAR_rxBufferLoopDetect
    #define UAR_RXBUFFER_OVERFLOW      UAR_rxBufferOverflow
#endif /* End UAR_RX_ENABLED */

#ifdef UAR_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG
    #define UAR_CONTROL                UAR_CONTROL_REG
#endif /* End UAR_BUART_sCR_SyncCtl_CtrlReg__CONTROL_REG */

#if(UAR_TX_ENABLED)
    #define UAR_TXDATA                 UAR_TXDATA_REG
    #define UAR_TXSTATUS               UAR_TXSTATUS_REG
    #define UAR_TXSTATUS_MASK          UAR_TXSTATUS_MASK_REG
    #define UAR_TXSTATUS_ACTL          UAR_TXSTATUS_ACTL_REG
    /* DP clock */
    #if(UAR_TXCLKGEN_DP)
        #define UAR_TXBITCLKGEN_CTR        UAR_TXBITCLKGEN_CTR_REG
        #define UAR_TXBITCLKTX_COMPLETE    UAR_TXBITCLKTX_COMPLETE_REG
    #else     /* Count7 clock*/
        #define UAR_TXBITCTR_PERIOD        UAR_TXBITCTR_PERIOD_REG
        #define UAR_TXBITCTR_CONTROL       UAR_TXBITCTR_CONTROL_REG
        #define UAR_TXBITCTR_COUNTER       UAR_TXBITCTR_COUNTER_REG
    #endif /* UAR_TXCLKGEN_DP */
#endif /* End UAR_TX_ENABLED */

#if(UAR_HD_ENABLED)
    #define UAR_TXDATA                 UAR_TXDATA_REG
    #define UAR_TXSTATUS               UAR_TXSTATUS_REG
    #define UAR_TXSTATUS_MASK          UAR_TXSTATUS_MASK_REG
    #define UAR_TXSTATUS_ACTL          UAR_TXSTATUS_ACTL_REG
#endif /* End UAR_HD_ENABLED */

#if( (UAR_RX_ENABLED) || (UAR_HD_ENABLED) )
    #define UAR_RXDATA                 UAR_RXDATA_REG
    #define UAR_RXADDRESS1             UAR_RXADDRESS1_REG
    #define UAR_RXADDRESS2             UAR_RXADDRESS2_REG
    #define UAR_RXBITCTR_PERIOD        UAR_RXBITCTR_PERIOD_REG
    #define UAR_RXBITCTR_CONTROL       UAR_RXBITCTR_CONTROL_REG
    #define UAR_RXBITCTR_COUNTER       UAR_RXBITCTR_COUNTER_REG
    #define UAR_RXSTATUS               UAR_RXSTATUS_REG
    #define UAR_RXSTATUS_MASK          UAR_RXSTATUS_MASK_REG
    #define UAR_RXSTATUS_ACTL          UAR_RXSTATUS_ACTL_REG
#endif /* End  (UAR_RX_ENABLED) || (UAR_HD_ENABLED) */

#if(UAR_INTERNAL_CLOCK_USED)
    #define UAR_INTCLOCK_CLKEN         UAR_INTCLOCK_CLKEN_REG
#endif /* End UAR_INTERNAL_CLOCK_USED */

#define UAR_WAIT_FOR_COMLETE_REINIT    UAR_WAIT_FOR_COMPLETE_REINIT

#endif  /* CY_UART_UAR_H */


/* [] END OF FILE */
