/*******************************************************************************
* File Name: pot_pin_gnd.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "pot_pin_gnd.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 pot_pin_gnd__PORT == 15 && ((pot_pin_gnd__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: pot_pin_gnd_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void pot_pin_gnd_Write(uint8 value) 
{
    uint8 staticBits = (pot_pin_gnd_DR & (uint8)(~pot_pin_gnd_MASK));
    pot_pin_gnd_DR = staticBits | ((uint8)(value << pot_pin_gnd_SHIFT) & pot_pin_gnd_MASK);
}


/*******************************************************************************
* Function Name: pot_pin_gnd_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  pot_pin_gnd_DM_STRONG     Strong Drive 
*  pot_pin_gnd_DM_OD_HI      Open Drain, Drives High 
*  pot_pin_gnd_DM_OD_LO      Open Drain, Drives Low 
*  pot_pin_gnd_DM_RES_UP     Resistive Pull Up 
*  pot_pin_gnd_DM_RES_DWN    Resistive Pull Down 
*  pot_pin_gnd_DM_RES_UPDWN  Resistive Pull Up/Down 
*  pot_pin_gnd_DM_DIG_HIZ    High Impedance Digital 
*  pot_pin_gnd_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void pot_pin_gnd_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(pot_pin_gnd_0, mode);
}


/*******************************************************************************
* Function Name: pot_pin_gnd_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro pot_pin_gnd_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 pot_pin_gnd_Read(void) 
{
    return (pot_pin_gnd_PS & pot_pin_gnd_MASK) >> pot_pin_gnd_SHIFT;
}


/*******************************************************************************
* Function Name: pot_pin_gnd_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 pot_pin_gnd_ReadDataReg(void) 
{
    return (pot_pin_gnd_DR & pot_pin_gnd_MASK) >> pot_pin_gnd_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(pot_pin_gnd_INTSTAT) 

    /*******************************************************************************
    * Function Name: pot_pin_gnd_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 pot_pin_gnd_ClearInterrupt(void) 
    {
        return (pot_pin_gnd_INTSTAT & pot_pin_gnd_MASK) >> pot_pin_gnd_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
